@@ -1,3 +1,4 @@
+import json
 import os
 import xml.dom.minidom
 
@@ -192,6 +193,11 @@ def get_mapping_choices():
     return vals
 
 
+def add_mapping_in_str(str_map_to, str_map_from, enrichment_name, include_default=True):
+    map_to_enrichment = json.load(str_map_to)
+    map_from_enrichment = json.load(str_map_from)
+    return add_mapping(map_to_enrichment, map_from_enrichment, enrichment_name, include_default)
+
 # to_map = {'UniqueId': 'uniqueId', 'username': 'user_name'}
 # from_map = {'score': '_a_score', 'confidence': '_a_confidence', 'reference': '_a_referenceId'}
 # mapping = add_mapping(to_map, from_map, 'custom', False)
