@@ -1,3 +1,5 @@
+import json
+
 from enrichwrap import CustomCallException
 
 enrich_targets = {}
@@ -117,6 +119,28 @@ def set_default_targets(http_url=None, http_port=None):
     return enrich_targets
 
 
+def add_post_target(which_enrich, url, body_json_str=None):
+    map_new_data = {"url": url, 'mechanism': 'POST'}
+    if body_json_str is not None:
+        dict = json.loads(body_json_str)
+        map_new_data['body'] = dict
+    else:
+        map_new_data['body'] = {}
+    return add_or_update_target(which_enrich, map_new_data)
+
+def add_get_target(which_enrich, url, param_json_str=None):
+    map_new_data = {"url": url, 'mechanism': 'GET'}
+    if param_json_str is not None:
+        dict = json.loads(param_json_str)
+        map_new_data['params'] = dict
+    else:
+        map_new_data['params'] = {}
+    return add_or_update_target(which_enrich, map_new_data)
+
+def add_target_with_map_str(which_enrich, str_map_new_data):
+    map_new_data = json.loads(str_map_new_data)
+    return add_or_update_target(which_enrich, map_new_data)
+
 def add_or_update_target(which_enrich, map_new_data):
     global enrich_targets
 
@@ -137,6 +161,7 @@ def add_or_update_target(which_enrich, map_new_data):
     enrich_targets[which_enrich] = map_new_data
     return enrich_targets
 
+
 def get_target(which_enrich):
     if len(enrich_targets) == 0:
         set_default_targets()
